@@ -3,6 +3,58 @@
 #+++ Dependencies: DataFunctions.R
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
+#' @export
+help_export <- function(
+  ### Overview of functions helping with exporting Data and Results
+){
+  ##author<< TW
+  ##details<<
+  ## Functions helping with exporting data
+  ## \itemize{
+  ## \item Export Input data from REddyProc class:
+  ##   \code{\link{sEddyProc_sExportData}}
+  ## \item Export Computed results from REddyProc class:
+  ##   \code{\link{sEddyProc_sExportResults}}
+  ## \item Write data frame to ASCII tab-separated text file:
+  ##   \code{\link{fWriteDataframeToFile}}
+  ## \item Write data frame to ASCII comma-separated text file with units in header row:
+  ##   \code{\link{fWriteFrench23}}
+  ## }
+  ##
+  ## Writing a file that can be supplied to the REddyProc webservice at
+  ## MPI-BGC Jena can be done by exporting data from REddyProc class \code{EProc}.
+  ##
+  ## \preformatted{
+  ## df <- EProc$sExportData()
+  ## fWriteDataframeToFile(df, "myfilename.txt", isSplitDatetime = TRUE)
+  ## }
+  ##
+  ## For preparing minimal working examples also consider
+  ## \itemize{
+  ## \item Omit records before the start of the first full day and the end of
+  ##   the last full day:
+  ##   \code{df <- \link{filter_entire_days}(df)}
+  ## \item Subset data.frame to one or two years:
+  ##   \code{df <- \link{filter_years_eop}(df, c(1998))}
+  ## }
+  ##
+  ## There are several functions that import from file of different formats.
+  ## \itemize{
+  ## \item Load text file with one header and one unit row into data frame:
+  ##   \code{\link{fLoadTXTIntoDataframe}}
+  ## \item Reads sequence of annual files in the format of Europe-fluxdata 2016:
+  ##   \code{\link{fLoadEuroFlux16}}
+  ## \item Read basic variables from Ameriflux standard (as of 2022) files:
+  ##   \code{\link{fLoadAmeriflux22}}
+  ## \item Read NetCDF files -> moved to separate package REddyProcNCDF
+  ##   (https://github.com/bgctw/REddyProcNCDF)
+  ## }
+  ##
+  ## Back to \link{REddyProc-package}.
+  "type ?help_export"
+}
+
+
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 #+++ Load ascii format data
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -13,6 +65,8 @@ fLoadTXTIntoDataframe <- function(
   ## Load text file with one header and one unit row into data frame
   ##description<<
   ## If gaps with the flag -9999.0 exist, these are set to NA.
+  ##seealso<<
+  ##  \code{\link{help_export}}
   FileName  = FileName.s  ##<< File name as a character string
   , Dir = if (!missing(Dir.s)) Dir.s else ''##<< Directory as a character string
   , FileName.s             ##<< deprecated
@@ -65,7 +119,7 @@ fLoadTXTIntoDataframe <- function(
   ## }
 }
 
-#' Get the default units for given variables 
+#' Get the default units for given variables
 #'
 #' @param variable_names  string vector of variables to query units for
 #' @return string vector with units, NA for non-standard variables.
@@ -82,8 +136,8 @@ REddyProc_defaultunits <- function(variable_names) {
     "Ustar", "ms-1",
     "VPD", "hPa",
     "rH", "%",
-  ) 
-  df_units <- data.frame(varname = variable_names) %>% 
+  )
+  df_units <- data.frame(varname = variable_names) %>%
     left_join(df_all_units, by = "varname")
   df_units$unit
 }
@@ -113,20 +167,23 @@ fWriteDataframeToFile <- function(
   Data.F                ##<< Data frame
   , FileName = FileName.s           ##<< File base name as a string
   , Dir = if (!missing(Dir.s)) Dir.s else ''          ##<< Directory as a string
-  , Digits = if (!missing(Digits.n)) Digits.n else 5			##<<
-  ## (integer) number of digits, i.e. precision, for numeric values
+  , Digits = if (!missing(Digits.n)) Digits.n else 5			##<< (integer) number
+  ## of digits, i.e. precision, for numeric values
+  , isSplitDatetime = FALSE ##<< set to TRUE to create columns Year, DoY and Hour
   , FileName.s         ##<< deprecated
   , Dir.s              ##<< deprecated
   , Digits.n			     ##<< deprecated
 ) {
   ##author<<
-  ## AMM, KS
+  ## AMM, KS, TW
+  ##seealso<< \code{\link{help_export}} \code{\link{fSplitDateTime}}
   ##details<<
   ## Missing values are flagged as -9999.0
   # TEST: Data.F <- EddyData.F; FileName = 'none'; Dir <- 'inst / examples';
   # Set file name
   OutputFile.s <- fSetFile(FileName, Dir, F, 'fWriteDataframeToFile')
   # Convert NAs to gap flag
+  if (isTRUE(isSplitDatetime)) Data.F <- fSplitDateTime(Data.F)
   Data.F <- fConvertNAsToGap(Data.F)
   # Write tab delimited file
   Lines.V.s <- vector(mode = 'character', length = 2)
@@ -152,6 +209,24 @@ attr(fWriteDataframeToFile, 'ex') <- function() {
   fWriteDataframeToFile(Example_DETha98, 'OutputTest.txt', Dir = Dir)
 }
 
+#' @export
+fSplitDateTime <- function(
+  ### Replace Column DateTime by columns Year, DoY, and Hour in a data.frame
+  df ##<< data.frame with column DateTime
+) {
+  ##seealso<< \code{\link{fWriteDataframeToFile}}
+  ##details<<
+  ## This function helps exporting to the format required by the
+  ## REddyProc web interface with columns Year, DoY, and Hour
+  df_ydh <- df %>% mutate(
+    Year = as.POSIXlt(.data$DateTime)$year + 1900,
+    DoY = as.POSIXlt(.data$DateTime)$yday + 1 ,
+    Hour = as.POSIXlt(.data$DateTime)$hour + as.POSIXlt(.data$DateTime)$min/60
+  ) %>%
+    select(.data$Year, .data$DoY, .data$Hour, !.data$DateTime)
+  df_ydh
+}
+
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 #+++ File handling
 #+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
